/**
 * Hospital Service System (HSS)
 *
 * Copyright (c) 2001/2002 Distributed Systems Research Group.
 * All rights reserved.
 *
 * For more information on Distributed Systems Research Group (DSRG),
 * please see <http://www.ics.agh.edu.pl/>.
 */


package org.dsrg.util;


/**
 * The class represents a set of assert methods
 *
 * @author <a href="mailto:bajolek@student.uci.agh.edu.pl">Maciej Bajoek</a>
 * @author <a href="mailto:artkas@student.uci.agh.edu.pl">Artur Kaszczyszyn</a>
 *
 * @version $Id: Assert.java,v 1.2 2002/07/24 16:31:24 maciek Exp $
 */
public class Assert
{
    private Assert()
    {

    }

    public static void notNull(String msg, Object obj)
    {
        if (obj == null)
        {
            Assert.fail(msg);
        }
    }

    public static void isTrue(boolean condition)
    {
        Assert.isTrue(null, condition);
    }

    public static void isTrue(String msg, boolean condition)
    {
        if (!condition)
        {
            Assert.fail(msg);
        }
    }

    public static void equals(Object expected, Object actual)
    {
        Assert.equals(null, expected, actual);
    }

    public static void equals(String msg, Object expected, Object actual)
    {
        if (expected == null && actual == null)
        {
            return;
        }

        if (expected != null && expected.equals(actual))
        {
            return;
        }

        Assert.fail(msg);
    }

    public static void notEquals(Object expected, Object actual)
    {
        Assert.notEquals(null, expected, actual);
    }

    public static void notEquals(String msg, Object expected, Object actual)
    {
        if (expected == null && actual == null)
        {
            Assert.fail(msg);
        }

        if (expected != null && !expected.equals(actual))
        {
            return;
        }
    }

    public static void fail()
    {
        Assert.fail(null);
    }

    public static void fail(String msg)
    {
        throw new IllegalArgumentException(msg);
    }











}










