/**
 * Hospital Service System (HSS)
 *
 * Copyright (c) 2001/2002 Distributed Systems Research Group.
 * All rights reserved.
 *
 * For more information on Distributed Systems Research Group (DSRG),
 * please see <http://www.ics.agh.edu.pl/>.
 */

package org.dsrg.util.log;

import org.dsrg.util.config.BootConfig;

import org.dsrg.exceptions.SystemException;

import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.apache.log4j.Priority;
import org.apache.log4j.PropertyConfigurator;
import org.apache.log4j.BasicConfigurator;

import java.io.IOException;
import java.io.InputStream;

import java.util.Properties;

/**
 * The class represents log service for the system
 *
 * @author <a href="mailto:bajolek@student.uci.agh.edu.pl">Maciej Bajoek</a>
 * @author <a href="mailto:artkas@student.uci.agh.edu.pl">Artur Kaszczyszyn</a>
 * @author <a href="mailto:dr@agh.edu.pl">Dominik Radziszowski</a>
 * 
 * @version $Id: Log.java,v 1.6  10-03-2003 Exp $
 */

public class Log {
	private static Log instance = new Log();

	private static boolean isInit = false;

	private static final Logger logger = Logger.getLogger("dsrg.monit");

	private void init() {
		if (Log.isInit) {
			return;
		}

		String file =
			BootConfig.getProperty(
				BootConfig.LOG_FILE_NAME,
				BootConfig.LOG_FILE_NAME_DEFAULT);
		System.out.println(
			"Initializing logging subsystem using file: " + file);

		InputStream is = null;
		is = Log.instance.getClass().getResourceAsStream(file);

		try {
			Properties props = new Properties();
			if (is != null) {
				props.load(is);

				PropertyConfigurator.configure(props);
				Log.isInit = true;
				System.out.println("Logging subsystem initialized successfuly");
			} else {
				System.out.println("Could not find config file - using default config");
				Log.isInit = true;
			}
		} catch (Exception e) {
			throw new SystemException("Initializing log service ... failed", e);
		} finally {
			if (is != null) {
				try {
					is.close();
					is = null;
				} catch (Exception e) {
					// ignore it
				}
			}
		}

	}

	private void destroy() {
		if (!Log.isInit) {
			return;
		}

		if (Log.logger != null) {
			LogManager.shutdown();
		}

		Log.isInit = false;
	}

	public static void debug(String msg) {
		Log.doLog(Priority.DEBUG, msg, null);
	}

	public static void debug(String msg, Throwable cause) {
		Log.doLog(Priority.DEBUG, msg, cause);
	}

	public static void debug(Throwable cause) {
		Log.doLog(Priority.DEBUG, cause.getMessage(), cause);
	}

	public static boolean isDebugEnabled() {
		return Log.doIsEnabledFor(Priority.DEBUG);
	}

	public static void info(String msg) {
		Log.doLog(Priority.INFO, msg, null);
	}

	public static void info(String msg, Throwable cause) {
		Log.doLog(Priority.INFO, msg, cause);
	}

	public static void info(Throwable cause) {
		Log.doLog(Priority.DEBUG, cause.getMessage(), cause);
	}

	public static boolean isInfoEnabled() {
		return Log.doIsEnabledFor(Priority.INFO);
	}

	public static void warn(String msg) {
		Log.doLog(Priority.WARN, msg, null);
	}

	public static void warn(String msg, Throwable cause) {
		Log.doLog(Priority.WARN, msg, cause);
	}

	public static void warn(Throwable cause) {
		Log.doLog(Priority.WARN, cause.getMessage(), cause);
	}

	public static boolean isWarnEnabled() {
		return Log.doIsEnabledFor(Priority.WARN);
	}

	public static void error(String msg) {
		Log.doLog(Priority.ERROR, msg, null);
	}

	public static void error(String msg, Throwable cause) {
		Log.doLog(Priority.ERROR, msg, cause);
	}

	public static void error(Throwable cause) {
		Log.doLog(Priority.ERROR, cause.getMessage(), cause);
	}

	public static boolean isErrorEnabled() {
		return Log.doIsEnabledFor(Priority.ERROR);
	}

	public static void fatal(String msg) {
		Log.doLog(Priority.FATAL, msg, null);
	}

	public static void fatal(String msg, Throwable cause) {
		Log.doLog(Priority.FATAL, msg, cause);
	}

	public static void fatal(Throwable cause) {
		Log.doLog(Priority.FATAL, cause.getMessage(), cause);
	}

	public static boolean isFatalEnabled() {
		return doIsEnabledFor(Priority.FATAL);
	}

	public static boolean doIsEnabledFor(Priority priority) {
		if (!Log.isInit) {
			throw new IllegalStateException("Log service not initialize");
		}

		return Log.logger.isEnabledFor(priority);
	}

	public static void doLog(Priority priority, String msg, Throwable cause) {
		/*
		if (!Log.isInit)
		{
		    throw new IllegalStateException("Log service not initialize");
		}
		*/
		Log.instance.init();

		if (msg == null) {
			throw new IllegalArgumentException("Log message not specified");
		}

		Log.logger.log(
			Log.instance.getClass().getName(),
			priority,
			msg,
			cause);
	}
}
